generate_dirichlet_clusters: Draws from a Dirichlet distribution and shows the clusters
that were generated by this draw. Varying alpha, will
put more or less mass in the first clusters compared to
higher clusters (rhos).
Description
Draws from a Dirichlet distribution and shows the clusters
that were generated by this draw. Varying alpha, will
put more or less mass in the first clusters compared to
higher clusters (rhos).
Usage
generate_dirichlet_clusters(a, K)
Arguments
a
Parameter that will be passed in to a Gamma distribution
in order to draw from the Dirichlet distribution.